@@ -110,8 +110,8 @@ class Akinator():
         try:
             exclude=requests.post(f"{self.ENDPOINT}exclude",json=self.json)
             exclude=exclude.json()
-            self.json["step"]=int(self.json["step"])
-            self.json["progression"]=float(self.json["progression"])
+            self.json["step"]=int(exclude["step"])
+            self.json["progression"]=float(exclude["progression"])
             self.step=int(exclude["step"])
             self.progression=float(exclude["progression"])
             self.question=exclude["question"]
